About BioSimulators-MASSpy
=============================

License
-------
This package is released under the `MIT License <https://github.com/biosimulators/Biosimulators_MASSpy/blob/dev/LICENSE>`_. MASSpy is released under the `MIT <https://spdx.org/licenses/MIT.html>`_.

Development team
----------------
This package was developed by the `Karr Lab <https://www.karrlab.org>`_ at the Icahn School of Medicine at Mount Sinai and the `Center for Reproducible Biomedical Modeling <https://reproduciblebiomodels.org/>`_. MASSpy was developed by the `Systems Biology Research Group <https://systemsbiology.ucsd.edu/>`_ at the `University of California, San Diego <https://ucsd.edu/>`_.

Questions and comments
-------------------------
Please contact the `BioSimulators Team <mailto:info@biosimulators.org>`_ with any questions or comments about the command-line program or Docker image. Please address questions and comments about MASSpy to `Zachary Haiman <zhaiman@eng.ucsd.edu>`_.
